---
# generated by https://github.com/hashicorp/terraform-plugin-docs
page_title: "vercel_project Resource - terraform-provider-vercel"
subcategory: ""
description: |-
  Provides a Project resource.
  A Project groups deployments and custom domains. To deploy on Vercel, you need to create a Project.
  For more detailed information, please see the Vercel documentation https://vercel.com/docs/concepts/projects/overview.
  -> The root_directory field behaves slightly differently to the Vercel website as
  it allows upward path navigation (../). This is deliberately done so a vercel_file or vercel_project_directory
  data source's path field can exactly match the root_directory.
  ~> If you are creating Deployments through terraform and intend to use both preview and production
  deployments, you may not want to create a Project within the same terraform workspace as a Deployment.
---

# vercel_project (Resource)

Provides a Project resource.

A Project groups deployments and custom domains. To deploy on Vercel, you need to create a Project.

For more detailed information, please see the [Vercel documentation](https://vercel.com/docs/concepts/projects/overview).

-> The `root_directory` field behaves slightly differently to the Vercel website as
it allows upward path navigation (`../`). This is deliberately done so a `vercel_file` or `vercel_project_directory`
data source's `path` field can exactly match the `root_directory`.

~> If you are creating Deployments through terraform and intend to use both preview and production
deployments, you may not want to create a Project within the same terraform workspace as a Deployment.

## Example Usage

```terraform
# A project that is connected to a git repository.
# Deployments will be created automatically
# on every branch push and merges onto the Production Branch.
resource "vercel_project" "with_git" {
  name           = "example_project_with_git"
  framework      = "create-react-app"
  root_directory = "ui"

  environment = [
    {
      key    = "bar"
      value  = "baz"
      target = ["preview"]
    }
  ]

  git_repository = {
    type = "github"
    repo = "vercel/some-repo"
  }
}

# A project that is not connected to a git repository.
# Deployments will need to be created manually through
# terraform, or via the vercel CLI.
resource "vercel_project" "example" {
  name           = "example_project"
  framework      = "create-react-app"
  root_directory = "packages/ui"

  environment = [
    {
      key    = "bar"
      value  = "baz"
      target = ["preview"]
    }
  ]
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- **name** (String) The desired name for the project.

### Optional

- **build_command** (String) The build command for this project. If omitted, this value will be automatically detected.
- **dev_command** (String) The dev command for this project. If omitted, this value will be automatically detected.
- **environment** (Attributes List) A list of environment variables that should be configured for the project. (see [below for nested schema](#nestedatt--environment))
- **framework** (String) The framework that is being used for this project. If omitted, no framework is selected.
- **git_repository** (Attributes) The Git Repository that will be connected to the project. When this is defined, any pushes to the specified connected Git Repository will be automatically deployed. This requires the corresponding Vercel for [Github](https://vercel.com/docs/concepts/git/vercel-for-github), [Gitlab](https://vercel.com/docs/concepts/git/vercel-for-gitlab) or [Bitbucket](https://vercel.com/docs/concepts/git/vercel-for-bitbucket) plugins to be installed. (see [below for nested schema](#nestedatt--git_repository))
- **install_command** (String) The install command for this project. If omitted, this value will be automatically detected.
- **output_directory** (String) The output directory of the project. When null is used this value will be automatically detected.
- **public_source** (Boolean) Specifies whether the source code and logs of the deployments for this project should be public or not.
- **root_directory** (String) The name of a directory or relative path to the source code of your project. When null is used it will default to the project root.
- **team_id** (String) The team ID to add the project to.

### Read-Only

- **id** (String) The ID of this resource.

<a id="nestedatt--environment"></a>
### Nested Schema for `environment`

Optional:

- **id** (String) The ID of the environment variable
- **key** (String) The name of the environment variable.
- **target** (Set of String) The environments that the environment variable should be present on. Valid targets are either `production`, `preview`, or `development`.
- **value** (String) The value of the environment variable.


<a id="nestedatt--git_repository"></a>
### Nested Schema for `git_repository`

Optional:

- **repo** (String) The name of the git repository. For example: `vercel/next.js`.
- **type** (String) The git provider of the repository. Must be either `github`, `gitlab`, or `bitbucket`.

## Import

Import is supported using the following syntax:

```shell
terraform import vercel_project.example team_xxxxxxxxxxxxxxxxxxxxxxxx/prj_xxxxxxxxxxxxxxxxxxxxxxxxxxxx
```
